import { ColumnDef } from "@tanstack/react-table";
import {Agency} from "@/types";
import { Label } from "@/Components/ui/label";
import { Switch } from "@/Components/ui/switch";
import { Button } from "@/Components/ui/button";
import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuTrigger,
} from "@/Components/ui/dropdown-menu";
import {
    Dialog,
    DialogClose,
    DialogContent,
    DialogDescription,
    DialogFooter,
    DialogHeader,
    DialogTitle,
    DialogTrigger,
} from "@/Components/ui/dialog";
import { SlidersHorizontal } from 'lucide-react';
import {router} from "@inertiajs/react";

import moment from 'moment'



export const columns: ColumnDef<Agency>[] = [
  {
    accessorKey: "name",
    header: "Name",
  },
  {
    accessorKey: "is_active",
    header: "Status",
    cell: ({ row }) =>{
        const agency = row.original

        return (
            <div className="flex items-center space-x-2">
              <Switch
              onClick={() =>
                router.post(route('change.agency.status',agency.uuid))
            }
              id="airplane-mode" checked={agency.is_active} />
              <Label htmlFor="airplane-mode"></Label>
            </div>
          )
    }
  },
  {
    // accessorKey: "created_at",
    header: "Created At",
    accessorFn: (data) => {
        return moment(data.created_at)
          .format("DD-MMM-YYYY")
      }
  },
  {
    accessorKey: "actions",
    header: "Actions",
    cell: ({ row }) => {
        const user = row.original

        return (
            <Dialog>
                <DropdownMenu>
                    <DropdownMenuTrigger>
                        <strong>  <SlidersHorizontal size={16} strokeWidth={2} absoluteStrokeWidth /></strong>
                    </DropdownMenuTrigger>
                    <DropdownMenuContent>
                        <DropdownMenuItem>
                            <DialogTrigger className="cursor-pointer text-red-500">
                                Delete
                            </DialogTrigger>

                        </DropdownMenuItem>
                    </DropdownMenuContent>
                </DropdownMenu>
                <DialogContent>
                    <DialogHeader>
                        <DialogTitle>Are you sure?</DialogTitle>
                        <DialogDescription>
                            Do you want to delete the entry? Deleting this entry cannot be
                            undone.
                        </DialogDescription>
                    </DialogHeader>
                    <DialogFooter>
                        <DialogClose asChild>
                            <Button variant="outline">Cancel</Button>
                        </DialogClose>
                        <DialogTrigger className={'bg-black px-4 rounded text-white'} onClick={() =>
                            router.delete(route('agencies.destroy',user.uuid))
                        }>
                            Delete
                        </DialogTrigger>
                    </DialogFooter>
                </DialogContent>
            </Dialog>

        )
      }
  }

]
